fnss.topologies.datacenter.two_tier_topology — FNSS 0.1.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »

# fnss.topologies.datacenter.two_tier_topology

`two_tier_topology`(n_core, n_edge, n_servers)

  Return a two-tier datacenter topology.

  This topology comprises switches organized in two tiers (core and edge) and servers connected to edge routers. Each core switch is connected to each edge switch while each server is connected to exactly one edge switch.

  Each node has two attributes:
    - type: can either be switch or server
    - tier: can either be core, edge or leaf. Nodes in the leaf tier are only server, while all core and edge nodes are switches.

  Each edge has an attribute type as well which can either be ‘core_edge’ if it connects a core and an edge switch or ‘edge_leaf’ if it connects an edge switch to a server.

  Parameters : | n_core : int Total number of core switches n_edge : int Total number of edge switches n_servers : int Number of servers connected to each edge switch.
  Returns : | topology : DatacenterTopology

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »